
package com.sap.dbtechdev.wrapper;


import java.lang.reflect.*;
import java.io.PrintWriter;
/**
 *
 */
class MinimalJDBCWrapper
    extends JDBCWrapper
{
    public static final String connectionC = "java.sql.Connection";
    public static final String statementC = "java.sql.Statement";
    public static final String preparedC = "java.sql.PreparedStatement";
    public static final String callableC = "java.sql.CallableStatement";
    public static final String resultsetC = "java.sql.ResultSet";
    static final String [][] tracedMethods = {
        {connectionC, "prepareStatement"},
        {connectionC, "prepareCall"},
        {statementC,  "execute"},
        {statementC,  "executeUpdate"},
        {statementC,  "executeQuery"},
        {resultsetC,  "next"}
    };
    /**
     * MinimalJDBCWrapper constructor
     */
    MinimalJDBCWrapper (
        WrapperOptions optionsP)
    {
        super (optionsP, new String [] {
            "Connection",
            "Statement",
            "PreparedStatement",
            "CallableStatement",
            "ResultSet",
            });
    }
    /**
     *
     */
    protected void genParameterEntry(
        Method method,
        PrintWriter outstream)
    {
        String className = method.getDeclaringClass ().getName ();
        String methodName = method.getName ();
        for (int i = 0; i < tracedMethods.length; ++i) {
            if (className.equals (tracedMethods [i] [0])
                    && methodName.equals (tracedMethods [i] [1])) {
                this.genParameterPrint (method, "this.printer", outstream);
                return;
            }
        }
        super.genParameterEntry (method, outstream);
    }
    /**
     *
     */
    protected void genExceptionHandling (
        Method method,
        String exceptionVar,
        PrintWriter outstream)
    {
        String className = method.getDeclaringClass ().getName ();
        String methodName = method.getName ();
        for (int i = 0; i < tracedMethods.length; ++i) {
            if (className.equals (tracedMethods [i] [0])
                    && methodName.equals (tracedMethods [i] [1])) {
                this.genExceptionPrint (method, "this.printer", exceptionVar, outstream);
                return;
            }
        }
        super.genExceptionHandling (method, exceptionVar, outstream);
    }
    /**
     *
     */
    protected void genReturn (
        Method method,
        String resultVar,
        PrintWriter outstream)
    {
        String className = method.getDeclaringClass ().getName ();
        String methodName = method.getName ();
        for (int i = 0; i < tracedMethods.length; ++i) {
            if (className.equals (tracedMethods [i] [0])
                    && methodName.equals (tracedMethods [i] [1])) {
                this.genResultvarPrint (method, "this.printer", resultVar, outstream);
                if (methodName.equals ("next") &&
                        className.equals ("java.sql.ResultSet")) {
                    outstream.println ("        if (_result) {");
                    outstream.println ("            int colCount = this._inner.getMetaData ().getColumnCount ();");
                    outstream.println ("            this.printer.print (\"row: \");");
                    outstream.println ("            for (int i = 0; i <= colCount; ++i) {");
                    outstream.println ("                this.printer.print (\"|\" + this._inner.getObject (i));");
                    outstream.println ("            }");
                    outstream.println ("            this.printer.println ();");
                    outstream.println ("        }");
                }
                return;
            }
        }
        super.genReturn (method, resultVar, outstream);
    }
    /**
     *
     */
    static WrapperOptions getOptions (
        String [] args)
    {
        WrapperOptions options = new WrapperOptions ();
        options.setTargetPackage ("com.sap.testpackage");
        options.setHelperVars (new HelperVar[] {new HelperVar ("printer", "java.io.PrintStream")});
        return options;
    }
    /**
     * main: called from the command line
     */
    static public void main (String [] args)
    throws ClassNotFoundException, java.io.IOException
    {
        WrapperOptions options = getOptions (args);
        JDBCWrapper wrapper = new MinimalJDBCWrapper (options);
        wrapper.genWrapper ();
    }
}

